'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createEncryptor = createEncryptor;
exports.createProgressiveEncryptor = createProgressiveEncryptor;

var _cryptoJs = require('crypto-js');

var _cryptoJs2 = _interopRequireDefault(_cryptoJs);

var _reduxPersist = require('redux-persist');

var _jsonStringifySafe = require('json-stringify-safe');

var _jsonStringifySafe2 = _interopRequireDefault(_jsonStringifySafe);

var _ProgressiveCryptor = require('./ProgressiveCryptor');

var _ProgressiveCryptor2 = _interopRequireDefault(_ProgressiveCryptor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function makeEncryptor(secretKey, progressive) {
  return function (state, key) {
    if (typeof state !== 'string') {
      state = (0, _jsonStringifySafe2.default)(state);
    }

    if (progressive) {
      new _ProgressiveCryptor2.default(state, secretKey).encrypt(function (encryptedState) {
        return encryptedState;
      });
    }

    return _cryptoJs2.default.AES.encrypt(state, secretKey).toString();
  };
}

function makeDecryptor(secretKey, progressive) {
  return function (state, key) {
    if (typeof state !== 'string') {
      if (process.env.NODE_ENV !== 'production') {
        console.error('redux-persist-transform-encrypt: expected outbound state to be a string');
      }

      return state;
    }

    try {
      if (progressive) {
        new _ProgressiveCryptor2.default(state, secretKey).decrypt(function (decryptedState) {
          return JSON.parse(decryptedState.toString(_cryptoJs2.default.enc.Utf8));
        });
      } else {
        var bytes = _cryptoJs2.default.AES.decrypt(state, secretKey);
        var newState = JSON.parse(bytes.toString(_cryptoJs2.default.enc.Utf8));

        return newState;
      }
    } catch (err) {
      if (process.env.NODE_ENV !== 'production') {
        console.error(err);
      }

      return null;
    }
  };
}

function createEncryptor(config) {
  var inbound = makeEncryptor(config.secretKey);
  var outbound = makeDecryptor(config.secretKey);

  return (0, _reduxPersist.createTransform)(inbound, outbound, config);
}

function createProgressiveEncryptor(config) {
  var inbound = makeEncryptor(config.secretKey, true);
  var outbound = makeDecryptor(config.secretKey, true);

  return (0, _reduxPersist.createTransform)(inbound, outbound, config);
}

exports.default = createEncryptor;